--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.MESA.WindowPos
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
--------------------------------------------------------------------------------

module Graphics.GL.MESA.WindowPos (
  -- * Extension Support
  glGetMESAWindowPos,
  gl_MESA_window_pos,
  -- * Functions
  glWindowPos2dMESA,
  glWindowPos2dvMESA,
  glWindowPos2fMESA,
  glWindowPos2fvMESA,
  glWindowPos2iMESA,
  glWindowPos2ivMESA,
  glWindowPos2sMESA,
  glWindowPos2svMESA,
  glWindowPos3dMESA,
  glWindowPos3dvMESA,
  glWindowPos3fMESA,
  glWindowPos3fvMESA,
  glWindowPos3iMESA,
  glWindowPos3ivMESA,
  glWindowPos3sMESA,
  glWindowPos3svMESA,
  glWindowPos4dMESA,
  glWindowPos4dvMESA,
  glWindowPos4fMESA,
  glWindowPos4fvMESA,
  glWindowPos4iMESA,
  glWindowPos4ivMESA,
  glWindowPos4sMESA,
  glWindowPos4svMESA
) where

import Graphics.GL.ExtensionPredicates
import Graphics.GL.Functions
