--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.PGI
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- A convenience module, combining all raw modules containing PGI extensions.
--
--------------------------------------------------------------------------------

module Graphics.GL.PGI (
  module Graphics.GL.PGI.MiscHints,
  module Graphics.GL.PGI.VertexHints
) where

import Graphics.GL.PGI.MiscHints
import Graphics.GL.PGI.VertexHints
