--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.SGI
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- A convenience module, combining all raw modules containing SGI extensions.
--
--------------------------------------------------------------------------------

module Graphics.GL.SGI (
  module Graphics.GL.SGI.ColorMatrix,
  module Graphics.GL.SGI.ColorTable,
  module Graphics.GL.SGI.TextureColorTable
) where

import Graphics.GL.SGI.ColorMatrix
import Graphics.GL.SGI.ColorTable
import Graphics.GL.SGI.TextureColorTable
