{-# LANGUAGE PatternSynonyms #-}
--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.ATI.FragmentShader
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
--------------------------------------------------------------------------------

module Graphics.GL.ATI.FragmentShader (
  -- * Extension Support
  glGetATIFragmentShader,
  gl_ATI_fragment_shader,
  -- * Enums
  pattern GL_2X_BIT_ATI,
  pattern GL_4X_BIT_ATI,
  pattern GL_8X_BIT_ATI,
  pattern GL_ADD_ATI,
  pattern GL_BIAS_BIT_ATI,
  pattern GL_BLUE_BIT_ATI,
  pattern GL_CND0_ATI,
  pattern GL_CND_ATI,
  pattern GL_COLOR_ALPHA_PAIRING_ATI,
  pattern GL_COMP_BIT_ATI,
  pattern GL_CON_0_ATI,
  pattern GL_CON_10_ATI,
  pattern GL_CON_11_ATI,
  pattern GL_CON_12_ATI,
  pattern GL_CON_13_ATI,
  pattern GL_CON_14_ATI,
  pattern GL_CON_15_ATI,
  pattern GL_CON_16_ATI,
  pattern GL_CON_17_ATI,
  pattern GL_CON_18_ATI,
  pattern GL_CON_19_ATI,
  pattern GL_CON_1_ATI,
  pattern GL_CON_20_ATI,
  pattern GL_CON_21_ATI,
  pattern GL_CON_22_ATI,
  pattern GL_CON_23_ATI,
  pattern GL_CON_24_ATI,
  pattern GL_CON_25_ATI,
  pattern GL_CON_26_ATI,
  pattern GL_CON_27_ATI,
  pattern GL_CON_28_ATI,
  pattern GL_CON_29_ATI,
  pattern GL_CON_2_ATI,
  pattern GL_CON_30_ATI,
  pattern GL_CON_31_ATI,
  pattern GL_CON_3_ATI,
  pattern GL_CON_4_ATI,
  pattern GL_CON_5_ATI,
  pattern GL_CON_6_ATI,
  pattern GL_CON_7_ATI,
  pattern GL_CON_8_ATI,
  pattern GL_CON_9_ATI,
  pattern GL_DOT2_ADD_ATI,
  pattern GL_DOT3_ATI,
  pattern GL_DOT4_ATI,
  pattern GL_EIGHTH_BIT_ATI,
  pattern GL_FRAGMENT_SHADER_ATI,
  pattern GL_GREEN_BIT_ATI,
  pattern GL_HALF_BIT_ATI,
  pattern GL_LERP_ATI,
  pattern GL_MAD_ATI,
  pattern GL_MOV_ATI,
  pattern GL_MUL_ATI,
  pattern GL_NEGATE_BIT_ATI,
  pattern GL_NUM_FRAGMENT_CONSTANTS_ATI,
  pattern GL_NUM_FRAGMENT_REGISTERS_ATI,
  pattern GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI,
  pattern GL_NUM_INSTRUCTIONS_PER_PASS_ATI,
  pattern GL_NUM_INSTRUCTIONS_TOTAL_ATI,
  pattern GL_NUM_LOOPBACK_COMPONENTS_ATI,
  pattern GL_NUM_PASSES_ATI,
  pattern GL_QUARTER_BIT_ATI,
  pattern GL_RED_BIT_ATI,
  pattern GL_REG_0_ATI,
  pattern GL_REG_10_ATI,
  pattern GL_REG_11_ATI,
  pattern GL_REG_12_ATI,
  pattern GL_REG_13_ATI,
  pattern GL_REG_14_ATI,
  pattern GL_REG_15_ATI,
  pattern GL_REG_16_ATI,
  pattern GL_REG_17_ATI,
  pattern GL_REG_18_ATI,
  pattern GL_REG_19_ATI,
  pattern GL_REG_1_ATI,
  pattern GL_REG_20_ATI,
  pattern GL_REG_21_ATI,
  pattern GL_REG_22_ATI,
  pattern GL_REG_23_ATI,
  pattern GL_REG_24_ATI,
  pattern GL_REG_25_ATI,
  pattern GL_REG_26_ATI,
  pattern GL_REG_27_ATI,
  pattern GL_REG_28_ATI,
  pattern GL_REG_29_ATI,
  pattern GL_REG_2_ATI,
  pattern GL_REG_30_ATI,
  pattern GL_REG_31_ATI,
  pattern GL_REG_3_ATI,
  pattern GL_REG_4_ATI,
  pattern GL_REG_5_ATI,
  pattern GL_REG_6_ATI,
  pattern GL_REG_7_ATI,
  pattern GL_REG_8_ATI,
  pattern GL_REG_9_ATI,
  pattern GL_SATURATE_BIT_ATI,
  pattern GL_SECONDARY_INTERPOLATOR_ATI,
  pattern GL_SUB_ATI,
  pattern GL_SWIZZLE_STQ_ATI,
  pattern GL_SWIZZLE_STQ_DQ_ATI,
  pattern GL_SWIZZLE_STRQ_ATI,
  pattern GL_SWIZZLE_STRQ_DQ_ATI,
  pattern GL_SWIZZLE_STR_ATI,
  pattern GL_SWIZZLE_STR_DR_ATI,
  -- * Functions
  glAlphaFragmentOp1ATI,
  glAlphaFragmentOp2ATI,
  glAlphaFragmentOp3ATI,
  glBeginFragmentShaderATI,
  glBindFragmentShaderATI,
  glColorFragmentOp1ATI,
  glColorFragmentOp2ATI,
  glColorFragmentOp3ATI,
  glDeleteFragmentShaderATI,
  glEndFragmentShaderATI,
  glGenFragmentShadersATI,
  glPassTexCoordATI,
  glSampleMapATI,
  glSetFragmentShaderConstantATI
) where

import Graphics.GL.ExtensionPredicates
import Graphics.GL.Tokens
import Graphics.GL.Functions
