--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.AMD
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- A convenience module, combining all raw modules containing AMD extensions.
--
--------------------------------------------------------------------------------

module Graphics.GL.AMD (
  module Graphics.GL.AMD.BlendMinmaxFactor,
  module Graphics.GL.AMD.DebugOutput,
  module Graphics.GL.AMD.DepthClampSeparate,
  module Graphics.GL.AMD.DrawBuffersBlend,
  module Graphics.GL.AMD.FramebufferMultisampleAdvanced,
  module Graphics.GL.AMD.FramebufferSamplePositions,
  module Graphics.GL.AMD.GPUShaderHalfFloat,
  module Graphics.GL.AMD.GPUShaderInt64,
  module Graphics.GL.AMD.InterleavedElements,
  module Graphics.GL.AMD.MultiDrawIndirect,
  module Graphics.GL.AMD.NameGenDelete,
  module Graphics.GL.AMD.OcclusionQueryEvent,
  module Graphics.GL.AMD.PerformanceMonitor,
  module Graphics.GL.AMD.PinnedMemory,
  module Graphics.GL.AMD.QueryBufferObject,
  module Graphics.GL.AMD.SamplePositions,
  module Graphics.GL.AMD.SeamlessCubemapPerTexture,
  module Graphics.GL.AMD.SparseTexture,
  module Graphics.GL.AMD.StencilOperationExtended,
  module Graphics.GL.AMD.TransformFeedback4,
  module Graphics.GL.AMD.VertexShaderTessellator
) where

import Graphics.GL.AMD.BlendMinmaxFactor
import Graphics.GL.AMD.DebugOutput
import Graphics.GL.AMD.DepthClampSeparate
import Graphics.GL.AMD.DrawBuffersBlend
import Graphics.GL.AMD.FramebufferMultisampleAdvanced
import Graphics.GL.AMD.FramebufferSamplePositions
import Graphics.GL.AMD.GPUShaderHalfFloat
import Graphics.GL.AMD.GPUShaderInt64
import Graphics.GL.AMD.InterleavedElements
import Graphics.GL.AMD.MultiDrawIndirect
import Graphics.GL.AMD.NameGenDelete
import Graphics.GL.AMD.OcclusionQueryEvent
import Graphics.GL.AMD.PerformanceMonitor
import Graphics.GL.AMD.PinnedMemory
import Graphics.GL.AMD.QueryBufferObject
import Graphics.GL.AMD.SamplePositions
import Graphics.GL.AMD.SeamlessCubemapPerTexture
import Graphics.GL.AMD.SparseTexture
import Graphics.GL.AMD.StencilOperationExtended
import Graphics.GL.AMD.TransformFeedback4
import Graphics.GL.AMD.VertexShaderTessellator
