--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.OES
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- A convenience module, combining all raw modules containing OES extensions.
--
--------------------------------------------------------------------------------

module Graphics.GL.OES (
  module Graphics.GL.OES.ByteCoordinates,
  module Graphics.GL.OES.CompressedPalettedTexture,
  module Graphics.GL.OES.FixedPoint,
  module Graphics.GL.OES.QueryMatrix,
  module Graphics.GL.OES.ReadFormat,
  module Graphics.GL.OES.SinglePrecision
) where

import Graphics.GL.OES.ByteCoordinates
import Graphics.GL.OES.CompressedPalettedTexture
import Graphics.GL.OES.FixedPoint
import Graphics.GL.OES.QueryMatrix
import Graphics.GL.OES.ReadFormat
import Graphics.GL.OES.SinglePrecision
