--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- A convenience module, combining the latest OpenGL compatibility profile plus
-- all extensions.
--
--------------------------------------------------------------------------------

module Graphics.GL (
  module Graphics.GL.Compatibility46,
  module Graphics.GL.GetProcAddress,
  module Graphics.GL.AMD,
  module Graphics.GL.APPLE,
  module Graphics.GL.ARB,
  module Graphics.GL.ATI,
  module Graphics.GL.EXT,
  module Graphics.GL.GREMEDY,
  module Graphics.GL.HP,
  module Graphics.GL.IBM,
  module Graphics.GL.INGR,
  module Graphics.GL.INTEL,
  module Graphics.GL.KHR,
  module Graphics.GL.MESA,
  module Graphics.GL.MESAX,
  module Graphics.GL.NV,
  module Graphics.GL.NVX,
  module Graphics.GL.OES,
  module Graphics.GL.OML,
  module Graphics.GL.OVR,
  module Graphics.GL.PGI,
  module Graphics.GL.REND,
  module Graphics.GL.S3,
  module Graphics.GL.SGI,
  module Graphics.GL.SGIS,
  module Graphics.GL.SGIX,
  module Graphics.GL.SUN,
  module Graphics.GL.SUNX,
  module Graphics.GL.ThreeDFX,
  module Graphics.GL.WIN
) where

import Graphics.GL.Compatibility46
import Graphics.GL.GetProcAddress
import Graphics.GL.AMD
import Graphics.GL.APPLE
import Graphics.GL.ARB
import Graphics.GL.ATI
import Graphics.GL.EXT
import Graphics.GL.GREMEDY
import Graphics.GL.HP
import Graphics.GL.IBM
import Graphics.GL.INGR
import Graphics.GL.INTEL
import Graphics.GL.KHR
import Graphics.GL.MESA
import Graphics.GL.MESAX
import Graphics.GL.NV
import Graphics.GL.NVX
import Graphics.GL.OES
import Graphics.GL.OML
import Graphics.GL.OVR
import Graphics.GL.PGI
import Graphics.GL.REND
import Graphics.GL.S3
import Graphics.GL.SGI
import Graphics.GL.SGIS
import Graphics.GL.SGIX
import Graphics.GL.SUN
import Graphics.GL.SUNX
import Graphics.GL.ThreeDFX
import Graphics.GL.WIN
