{-# LANGUAGE PatternSynonyms #-}
--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.GL.OES.FixedPoint
-- Copyright   :  (c) Sven Panne 2019
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
--------------------------------------------------------------------------------

module Graphics.GL.OES.FixedPoint (
  -- * Extension Support
  glGetOESFixedPoint,
  gl_OES_fixed_point,
  -- * Enums
  pattern GL_FIXED_OES,
  -- * Functions
  glAccumxOES,
  glAlphaFuncxOES,
  glBitmapxOES,
  glBlendColorxOES,
  glClearAccumxOES,
  glClearColorxOES,
  glClearDepthxOES,
  glClipPlanexOES,
  glColor3xOES,
  glColor3xvOES,
  glColor4xOES,
  glColor4xvOES,
  glConvolutionParameterxOES,
  glConvolutionParameterxvOES,
  glDepthRangexOES,
  glEvalCoord1xOES,
  glEvalCoord1xvOES,
  glEvalCoord2xOES,
  glEvalCoord2xvOES,
  glFeedbackBufferxOES,
  glFogxOES,
  glFogxvOES,
  glFrustumxOES,
  glGetClipPlanexOES,
  glGetConvolutionParameterxvOES,
  glGetFixedvOES,
  glGetHistogramParameterxvOES,
  glGetLightxOES,
  glGetMapxvOES,
  glGetMaterialxOES,
  glGetPixelMapxv,
  glGetTexEnvxvOES,
  glGetTexGenxvOES,
  glGetTexLevelParameterxvOES,
  glGetTexParameterxvOES,
  glIndexxOES,
  glIndexxvOES,
  glLightModelxOES,
  glLightModelxvOES,
  glLightxOES,
  glLightxvOES,
  glLineWidthxOES,
  glLoadMatrixxOES,
  glLoadTransposeMatrixxOES,
  glMap1xOES,
  glMap2xOES,
  glMapGrid1xOES,
  glMapGrid2xOES,
  glMaterialxOES,
  glMaterialxvOES,
  glMultMatrixxOES,
  glMultTransposeMatrixxOES,
  glMultiTexCoord1xOES,
  glMultiTexCoord1xvOES,
  glMultiTexCoord2xOES,
  glMultiTexCoord2xvOES,
  glMultiTexCoord3xOES,
  glMultiTexCoord3xvOES,
  glMultiTexCoord4xOES,
  glMultiTexCoord4xvOES,
  glNormal3xOES,
  glNormal3xvOES,
  glOrthoxOES,
  glPassThroughxOES,
  glPixelMapx,
  glPixelStorex,
  glPixelTransferxOES,
  glPixelZoomxOES,
  glPointParameterxvOES,
  glPointSizexOES,
  glPolygonOffsetxOES,
  glPrioritizeTexturesxOES,
  glRasterPos2xOES,
  glRasterPos2xvOES,
  glRasterPos3xOES,
  glRasterPos3xvOES,
  glRasterPos4xOES,
  glRasterPos4xvOES,
  glRectxOES,
  glRectxvOES,
  glRotatexOES,
  glScalexOES,
  glTexCoord1xOES,
  glTexCoord1xvOES,
  glTexCoord2xOES,
  glTexCoord2xvOES,
  glTexCoord3xOES,
  glTexCoord3xvOES,
  glTexCoord4xOES,
  glTexCoord4xvOES,
  glTexEnvxOES,
  glTexEnvxvOES,
  glTexGenxOES,
  glTexGenxvOES,
  glTexParameterxOES,
  glTexParameterxvOES,
  glTranslatexOES,
  glVertex2xOES,
  glVertex2xvOES,
  glVertex3xOES,
  glVertex3xvOES,
  glVertex4xOES,
  glVertex4xvOES
) where

import Graphics.GL.ExtensionPredicates
import Graphics.GL.Tokens
import Graphics.GL.Functions
